@@ -3,10 +3,9 @@
 
 import time
 import board
-import busio
 import adafruit_pct2075
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 pct = adafruit_pct2075.PCT2075(i2c)
 
 pct.high_temperature_threshold = 35.5
