@@ -1,10 +1,11 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 import time
 import board
-import busio
 import adafruit_pct2075
 
-i2c = busio.I2C(board.SCL, board.SDA)
-
+i2c = board.I2C()  # uses board.SCL and board.SDA
 pct = adafruit_pct2075.PCT2075(i2c)
 
 while True:
